@@ -82,8 +82,8 @@ typedef struct
 
 	GtkBin *header_bin;
 
-	gboolean renaming;
 	gboolean image_is_broken;
+	gchar * force_icon_name;  //show an icon instead of a thumbnail
 
 	gboolean delete_enabled;
 	guint gconf_conn_id;
@@ -94,8 +94,6 @@ typedef struct
 	gulong               notify_signal_id;
 } DocumentTilePrivate;
 
-static GnomeThumbnailFactory *thumbnail_factory = NULL;
-
 #define DOCUMENT_TILE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DOCUMENT_TILE_TYPE, DocumentTilePrivate))
 
 static void document_tile_class_init (DocumentTileClass *this_class)
@@ -110,6 +108,19 @@ static void document_tile_class_init (DocumentTileClass *this_class)
 	g_type_class_add_private (this_class, sizeof (DocumentTilePrivate));
 }
 
+//Use a specific icon instead of a thumbnail.
+GtkWidget *
+document_tile_new_force_icon (const gchar *in_uri, const gchar *mime_type, time_t modified, const gchar *icon)
+{
+	DocumentTile *this;
+	DocumentTilePrivate *priv;
+	
+	this = (DocumentTile *) document_tile_new (in_uri, mime_type, modified);
+	priv = DOCUMENT_TILE_GET_PRIVATE (this);
+	priv->force_icon_name = g_strdup (icon);
+	return GTK_WIDGET (this);
+}
+
 GtkWidget *
 document_tile_new (const gchar *in_uri, const gchar *mime_type, time_t modified)
 {
@@ -137,6 +148,8 @@ document_tile_new (const gchar *in_uri, const gchar *mime_type, time_t modified)
 	
 	gchar *filename;
 	gchar *tooltip_text;
+
+	libslab_checkpoint ("document_tile_new(): start");
   
 	uri = g_strdup (in_uri);
 
@@ -293,8 +306,6 @@ document_tile_new (const gchar *in_uri, const gchar *mime_type, time_t modified)
 
 	gtk_widget_show_all (GTK_WIDGET (TILE (this)->context_menu));
 
-	load_image (this);
-
 	accessible = gtk_widget_get_accessible (GTK_WIDGET (this));
 	if (basename)
 	  atk_object_set_name (accessible, basename);
@@ -304,6 +315,8 @@ document_tile_new (const gchar *in_uri, const gchar *mime_type, time_t modified)
 	g_free (basename);
 	g_free (time_str);
 
+	libslab_checkpoint ("document_tile_new(): end");
+
 	return GTK_WIDGET (this);
 }
 
@@ -328,8 +341,6 @@ document_tile_private_setup (DocumentTile *this)
 	else
 		priv->default_app = NULL;
 
-	priv->renaming = FALSE;
-
 	gnome_vfs_file_info_unref (info);
 
 	priv->delete_enabled =
@@ -362,8 +373,8 @@ document_tile_init (DocumentTile *tile)
 
 	priv->header_bin       = NULL;
 
-	priv->renaming         = FALSE;
 	priv->image_is_broken  = TRUE;
+	priv->force_icon_name  = NULL;
 
 	priv->delete_enabled   = FALSE;
 	priv->gconf_conn_id    = 0;
@@ -383,6 +394,7 @@ document_tile_finalize (GObject *g_object)
 
 	g_free (priv->basename);
 	g_free (priv->mime_type);
+	g_free (priv->force_icon_name);
 
 	gnome_vfs_mime_application_free (priv->default_app);
 
@@ -417,16 +429,21 @@ load_image (DocumentTile *tile)
 
 	gchar *icon_id = NULL;
 	gboolean free_icon_id = TRUE;
+	GnomeThumbnailFactory *thumbnail_factory;
 
-	if (! priv->mime_type || ! strstr (TILE (tile)->uri, "file://")) {
-		icon_id = "gnome-fs-regular";
+	libslab_checkpoint ("document-tile.c: load_image(): start for %s", TILE (tile)->uri);
+
+	if (priv->force_icon_name || ! priv->mime_type || ! strstr (TILE (tile)->uri, "file://")) {
+		if (priv->force_icon_name)
+			icon_id = priv->force_icon_name;
+		else
+			icon_id = "gnome-fs-regular";
 		free_icon_id = FALSE;
 
 		goto exit;
 	}
 
-	if (! thumbnail_factory)
-		thumbnail_factory = gnome_thumbnail_factory_new (GNOME_THUMBNAIL_SIZE_NORMAL);
+	thumbnail_factory = libslab_thumbnail_factory_get ();
 
 	thumb_path = gnome_thumbnail_factory_lookup (thumbnail_factory, TILE (tile)->uri, priv->modified);
 
@@ -467,6 +484,8 @@ exit:
 
 	if (free_icon_id && icon_id)
 		g_free (icon_id);
+
+	libslab_checkpoint ("document-tile.c: load_image(): end");
 }
 
 /* Next function taken from e-data-server-util.c in evolution-data-server */
